Getting started — PuntoPagos Python 0.1 documentation

### Navigation

- index
- PuntoPagos Python 0.1 documentation »

# Getting started

## Create a transaction

class `puntopagos.` `PuntoPagoRequest`(config, sandbox=False, ssl=True)
  `create`(trx_id, medio_pago, monto, detalle='')

    Create a request (and a transaction) to puntopagos.com.

    Parameters: | trx_id – Client unique transaction id (varchar(50)). medio_pago – Payment method id, valid ids in PUNTOPAGOS_PAYMENT_METHODS. monto – Transaction total amount. detalle – Transaction detail (optional).

  `create_headers`(authorization_string, now)

    Create standard headers for a puntopagos.com request

    Parameters: | authorization_string – Signable authorization string. now – struct_time usually returned by gmtime()

  `status`(token, trx_id, monto)

    Create a request for verify a transaction status

    Parameters: | token – Unique token, asigned by puntopagos to transaction. trx_id – Client unique transaction id (varchar(50)). monto – Transaction total amount.

### Navigation

- index
- PuntoPagos Python 0.1 documentation »